#
# spec file for package python-mox3
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pypi_name mox3
Name:           python-mox3
Version:        0.23.0
Release:        bp153.1.21
Summary:        An unofficial port of the Google mox framework to Python 3
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://bugs.launchpad.net/python-mox3
Source0:        https://files.pythonhosted.org/packages/source/m/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python2-fixtures >= 3.0.0
BuildRequires:  python2-pbr >= 2.0.0
BuildRequires:  python2-python-subunit >= 0.0.18
BuildRequires:  python2-setuptools >= 16.0
BuildRequires:  python2-testrepository >= 0.0.18
BuildRequires:  python2-testtools >= 1.4.0
BuildRequires:  python3-fixtures >= 3.0.0
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-python-subunit >= 0.0.18
BuildRequires:  python3-setuptools >= 16.0
BuildRequires:  python3-testrepository >= 0.0.18
BuildRequires:  python3-testtools >= 1.4.0
Requires:       python-fixtures >= 3.0.0
Requires:       python-pbr >= 2.0.0
BuildArch:      noarch
%python_subpackages

%description
Mox3 is an unofficial port of the Google mox framework to Python 3. It
was meant to be as compatible with mox as possible, but small
enhancements have been made. The library was tested on Python version
3.2, 2.7 and 2.6.

%package -n python-mox3-doc
Summary:        Documentation for %{name}
Group:          Documentation
BuildRequires:  python-Sphinx
BuildRequires:  python-openstackdocstheme >= 1.11.0

%description -n python-mox3-doc
Mox3 is an unofficial port of the Google mox framework to Python 3. It
was meant to be as compatible with mox as possible, but small
enhancements have been made. The library was tested on Python version
3.2, 2.7 and 2.6.

This package contains documentation in HTML format.

%prep
%autosetup -n %{pypi_name}-%{version}
%py_req_cleanup
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
%python_build

# generate html docs
%{__python2} setup.py build_sphinx

%check
%{python_expand rm -rf .testrepository
$python setup.py testr
}

%install
%python_install

%files %{python_files}
%license COPYING.txt
%doc README.rst
%{python2_sitelib}/%{pypi_name}
%{python2_sitelib}/%{pypi_name}-*.egg-info

%files -n python-mox3-doc
%license COPYING.txt
%doc doc/build/html

%changelog
* Fri Nov 24 2017 dmueller@suse.com
- update to version 0.23.0:
  * Update URLs in documents according to document migration
  * Update .gitignore
  * turn on warning-is-error flag for doc build
  * switch from oslosphinx to openstackdocstheme
  * rearrange existing documentation based on the new standard layout
* Wed Jun 17 2015 tbechtold@suse.com
- update to 0.8.0:
  * Fixes to allow a new release
  * Updated requirements
  * Add a fixture for consuming mox3 easily
  * Add CONTRIBUTING file
  * Cleaed up AUTHORS/ChangeLog file
  * Migrate test bases to testtools
  * Fix all of the flake8/hacking warnings
  * Fix the leading indentation issue
  * Updated to use OpenStack standards
  * Add openstack stuff
  * Changed project description
  * Author is not required - maintainer is enough
  * Added tests to sdist
  * Applied some changes according to http://getpython3.com/diveintopython3/packaging.html
  * Changed directory test to tests. Fixed travis config
  * Adjusted the structure of the mox3
  * Minor fixes + changes in metadata
  * Update README
  * Fixed pep8 issues
  * Added test for changed semantics in Python 3
  * Added modification info
  * Fixed isinstance check on instances of MockObject
  * Fixed a bug when dir() called on MockObject was not returning attributes of a mocked class (Python3)
  * Pep8's E111 error is now ignored
  * Removed exclamation mark from travis.yml
  * Added pep8 to .travis.yml
  * Fixed deprecation warnings in mox_test.py
  * Introduced class to which mocks can be bound in order to preserve binding information (Python3 and missing unbound methods issue)
  * Added __hash__ for MockMethod - no default hash in py3k
  * bugfix for unhashable/uncomparable dicts
  * Restored callable function since it's present in python 3.2
  * Converted all classes to the new style (inheriting from object) - this is the only option in py3k
  * Py3k always sets re.U flag, so the resulting regex.flags are equals to flags | re.U
  * Fixed all the simple compatiblity issues
  * Fixed compatiblity issues in stubout
  * Fixed some of the compatiblity issues
  * info about modification
  * Added modification info
  * Enabled Travis CI
  * Enabled Travis CI
  * Another bugfix... Tests are still passing
  * Bugfix. At least I hope so..
  * fixed indentation
  * bugfix
  * Added .gitignore
  * Updated to version 0.5.3
  * Numerous fixes from Google:
  * Mox release 0.5.1, which includes some bug fixes and tests for stubout
  * Fix for Issue 3, submitted by a...@therobots.org
  * Fix for Issue 5, submitted by agoratim
  * Patch from Matt Brown (mdbrow@gmail.com) to inspect the arguments of mocked methods. Alright! :)
  * Added support for __contains__, thanks to Adam Lowry
  * Added import for inspect, and tests for stubout. Patch by Manuel Holtgrewe
  * Remove duplicate NotTest. Bad patch
  * Add a Not comparator to compose with other comparators
  * Fix MoxTestBase to be usable with multiple-inheritance
  * Write a README
  * Start our first release at 0.5.0, not 1.0.0
  * Include the mox_test_helper.py in the distribution
  * Fix mailing list address
  * Initial import of mox (originally an internal Google project)
- Adjust Requires according to requirements.txt
* Mon Sep  2 2013 dmueller@suse.com
- Initial package (0.7.0)
